If you use Fiducia for work/research presented in a publication (whether 
directly, or as a dependency to another package), we encourage the following 
acknowledgement:

  This research made use of Fiducia, a community-developed Python package for 
  analysis of Dante signals.

and that you cite the following paper(s):

```bib
@article{barnak2020soft,
  title={Soft x-ray spectrum unfold of K-edge filtered x-ray diode arrays using cubic splines},
  author={Barnak, DH and Davies, JR and Knauer, JP and Kozlowski, Pawel Marek},
  journal={Review of Scientific Instruments},
  volume={91},
  number={7},
  pages={073102},
  year={2020},
  publisher={AIP Publishing LLC}
  url={https://doi.org/10.1063/5.0002856}
}
```